@@ -219,8 +219,8 @@ eigen_approx <- function(x,
                             ja        = x@colindices,
                             ia        = x@rowpointers,
                             v         = vector_dc("double", x@dimension[1]*ncv),
-                            dr        = vector_dc("double", nev),
-                            di        = vector_dc("double", nev),
+                            dr        = vector_dc("double", nev+1),
+                            di        = vector_dc("double", nev+1),
                             iparam    = integer_dc(8),
                             INTENT    = c("r", "r", "r", "r", "r", "r", "r", "r", "r",
                                           "rw", "rw", "rw", "rw"),
